%% Casticovy kompozit pri cistem smyku (invlap.m vs. gavsteh.m)

% parametry modelu
fm=0.8;						% podil matrice (viskoelasticka)
fi=1-fm;						% podil inkluze (elasticka)
Ei0=386;						% [GPa] 
Em0=21.04;					% [GPa]
E=[9902 3841 1911 747 404 105];		% [GPa]
tau=[0.001 0.01 0.1 1 10 100];		% [den]
M=length(E); 					% pocet clanku (matrice) 
nu_m=0.4;						% Poissonuv soucinitel matrice
nu_i=0.41;						% Poissonuv soucinitel inkluze
Gi0=Ei0/(2*(1+nu_i));			% [GPa] smykovy modul pruznosti inkluze (elasticka)	
Gm0=Em0/(2*(1+nu_m));		% [GPa] smykovy modul pruznosti (0-teho clanku matrice)
G=E/(2*(1+nu_m));				% [GPa] smykovy modul pruznosti (viskoelastickych clanku matrice)
Km0=2*Gm0*(1+nu_m)/(3*(1-2*nu_m));	% [GPa] objemovy modul pruznosti (0-teho clanku matrice)

% zatezovaci funkce
sgm=5;			% [MPa] amplituda smykoveho napeti 
om=pi/100; 
function y=f(t,sgm,om)	
	y=sgm*sin(om*t);		
end	

% vektor casu pro vyhodnoceni f(t)
t=linspace(0,100,9)'; 	% [den]
t(1)=0.1; 

% inverzni Laplaceova transformace (homogenizace metodou  Mori-Tanaka)
function[Y]=F_p(p,sgm,om,fm,Gi0,Gm0,G,tau,Km0,M)
F=sgm*om./(p.^2+om^2);	% Laplaceuv obraz zatezovaci funkce
fi=1-fm;	% funkce invlap.m muze mit jen 9 parametru
Jm_d=zeros(size(p));
for ii=1:length(p)
	Jm_d(ii)=1./(p(ii)*Gm0);
	for jj=1:M
		Jm_d(ii)=Jm_d(ii)+1/(G(jj)*tau(jj)*p(ii)*(p(ii)+1./tau(jj)));
	end
end
Jm_v=1./(p*Km0);	
Ji_d=1./(p*Gi0);
Beta_m=6*(Jm_d+2*Jm_v)./(5*(3*Jm_d+4*Jm_v));
Jeff_d=(fm+fi.*(1+Beta_m.*(Jm_d./Ji_d-1)).^-1) ...
		./(fm./Jm_d+fi./Ji_d.*(1+Beta_m.*(Jm_d./Ji_d-1)).^-1);
Y=p.*Jeff_d.*F; 
end
pol=0; 		
tol=1e-12; 		
L=22;
for v=1:length(t)
	tv=t(v);
	IL(v)=invlap('F_p',tv,pol,tol,sgm,om,fm,Gi0,Gm0,G,tau,Km0,M)*1000;
	GS(v)=gavsteh('F_p',tv,L,sgm,om,fm,Gi0,Gm0,G,tau,Km0,M)*1000;
end

%format long
format bank
% vysledne hodnoty obou algoritmu
[t f(t,sgm,om) IL' GS']










