%% Casticovy kompozit pri cistem smyku

% parametry modelu
fm=0.8;						% podil matrice (viskoelasticka)
fi=1-fm;						% podil inkluze (elasticka)
Ei0=386;						% [GPa] 
Em0=21.04;					% [GPa]
E=[9902 3841 1911 747 404 105];		% [GPa]
tau=[0.001 0.01 0.1 1 10 100];		% [den]
M=length(E); 					% pocet clanku (matrice) 
nu_m=0.4;						% Poissonuv soucinitel matrice
nu_i=0.41;						% Poissonuv soucinitel inkluze
Gi0=Ei0/(2*(1+nu_i));			% [GPa] smykovy modul pruznosti inkluze (elasticka)	
Gm0=Em0/(2*(1+nu_m));		% [GPa] smykovy modul pruznosti (0-teho clanku matrice)
G=E/(2*(1+nu_m));				% [GPa] smykovy modul pruznosti (viskoelastickych clanku matrice)
Km0=2*Gm0*(1+nu_m)/(3*(1-2*nu_m));	% [GPa] objemovy modul pruznosti (0-teho clanku matrice)

% zatezovaci funkce
sgm=5;			% [MPa] amplituda smykoveho napeti 
om=pi/100; 
function y=f(t,sgm,om)	
	y=sgm*sin(om*t);		
end	

% vektor casu pro vyhodnoceni f(t)
t=linspace(0,100,9)'; 	% [den]
t(1)=0.1; 

% exponencialni algoritmus (homogenizace metodou Mori-Tanaka)
n=1000;			% pocet kroku
dt=100/n;
u=1;
theta=exp(-dt./tau);
psi=tau.*(1-theta)./dt;
Gm=(1/Gm0+sum(1./G.*(1.-psi))).^-1;	% algoritnicka tuhost matrice
beta_m=(6*(Km0+2*Gm))/(5*(3*Km0+4*Gm));	% deviatoricka cast Eshelbyho tenzoru
z=1/(1+beta_m*(Gi0/Gm-1));			% pomocny vyraz
Am=1/(fm+fi*z);					% koncentracni deformacni faktor matrice (Mori-Tanaka ) 
Ai=z/(fm+fi*z);						% koncentracni deformacni faktor inkluze (Mori-Tanaka ) 
% kontrola: fm*Am + fi*Ai - 1 = 0
Geff=fm*Gm*Am+fi*Gi0*Ai;				% algoritnicka efektivni tuhost 
gam=0;
del_gam=0;
gam_p=zeros(1,M);
gam_n=zeros(1,M);
dgam_p=zeros(1,M);
dgam_n=zeros(1,M);
for i=1:n
	del_sgm=f(i*dt,sgm,om)-f((i-1)*dt,sgm,om);  
	d_gam_m=dt*psi*dgam_p';				% prirustek dotvarovani matrice

	% koncentracni deformacni faktory vlastniho napeti matrice a inkluze
	am=(1-Am)/(Gm-Gi0)*(Gm*d_gam_m); 		
        ai=(1-Ai)/(Gm-Gi0)*(Gm*d_gam_m); 		
	% kontrola: fm*am + fi*ai = 0
	
	del_gam=(del_sgm+fm*Am*Gm*d_gam_m)/Geff;
	del_gam_m=Am*del_gam+am;
        del_gam_i=Ai*del_gam+ai;
        % kontrola: del_gam - fm*del_gam_m - fi*del_gam_i = 0
	
	del_sgm_m= Gm*(del_gam_m-d_gam_m);
        del_sgm_i=Gi0*del_gam_i;
	% kontrola: del_sgm - fm*del_sgm_m - fi*del_sgm_i = 0
	
	dgam_n=theta.*dgam_p.+(1-theta)./(dt*G)*del_sgm_m;
	gam_n=gam_p.+dt*psi.*dgam_p.+(1-psi)*del_sgm_m./G;
	% kontrola: sum(gam_n-gam_p) + del_sgm_m/Gm0 - del_gam_m = 0
	
	dgam_p=dgam_n;
	gam_p=gam_n;
	
	gam =gam+del_gam;
	if i*dt==t(u), ea(u)=gam*1000; 
		u=u+1;
	end
end

% inverzni Laplaceova transformace (homogenizace metodou  Mori-Tanaka)
function[Y]=F_p(p,sgm,om,fm,Gi0,Gm0,G,tau,Km0,M)
F=sgm*om./(p.^2+om^2);	% Laplaceuv obraz zatezovaci funkce
fi=1-fm;	% funkce invlap.m muze mit jen 9 parametru
Jm_d=1./(p*Gm0) ...
	+1./p.*(1./(G.*tau)*(1./(p*ones(1,M)+1./(ones(length(p),1)*tau)))')';
Jm_v=1./(p*Km0);	
Ji_d=1./(p*Gi0);
Beta_m=6*(Jm_d+2*Jm_v)./(5*(3*Jm_d+4*Jm_v));
Jeff_d=(fm+fi.*(1+Beta_m.*(Jm_d./Ji_d-1)).^-1) ...
		./(fm./Jm_d+fi./Ji_d.*(1+Beta_m.*(Jm_d./Ji_d-1)).^-1);
Y=p.*Jeff_d.*F; 
end
pol=0; 		
tol=1e-12; 		
Lt=invlap('F_p',t,pol,tol,sgm,om,fm,Gi0,Gm0,G,tau,Km0,M)*1000;

%format long
format bank
% vysledne hodnoty obou algoritmu
[t f(t,sgm,om) Lt ea']










